"""RGB endpoint module."""

from __future__ import annotations

from typing import Any


def read(content: str) -> dict[str, Any]:
    """Read RGB data."""

    # Read the page content
    rgb: dict[str, Any] = {}

    return rgb
